"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const fs = require("fs-extra");
const path = require("path");
const prompts = require("prompts");
const config_file_1 = require("./lib/config-file");
class BaseCommand extends command_1.default {
    constructor() {
        super(...arguments);
        this.configFilePath = path.join(this.config.configDir, 'config.json');
    }
    async getConfig() {
        await fs.ensureDir(this.config.configDir);
        let configFile;
        try {
            await fs.access(this.configFilePath, fs.constants.F_OK);
            const json = await fs.readJson(this.configFilePath);
            configFile = new config_file_1.ConfigFile(json);
        }
        catch (_a) {
            configFile = new config_file_1.ConfigFile();
            await this.saveConfig(configFile);
        }
        return configFile;
    }
    async saveConfig(config) {
        await fs.ensureDir(this.config.configDir);
        await fs.writeFile(this.configFilePath, config.toString());
    }
    async promptInput(args) {
        const response = await prompts({
            type: 'text',
            name: 'result',
            message: args.message,
            initial: args.default,
            validate: args.validator
        });
        return response.result;
    }
    async promptConfirm(args) {
        const response = await prompts({
            type: 'confirm',
            name: 'result',
            message: args.message,
            initial: args.default || false
        });
        return response.result;
    }
    async promptChoices(args) {
        const response = await prompts({
            type: 'select',
            name: 'result',
            message: args.message,
            choices: args.choices.map((choice) => {
                return { title: choice, value: choice };
            })
        });
        return response.result;
    }
}
exports.default = BaseCommand;
